#
# spec file for package nautilus-image-converter
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2007-2010 Dominique Leuenberger, Amsterdam, The Netherlands.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define nautilus_extdir %(pkg-config --variable=extensiondir libnautilus-extension-4)

Name:           nautilus-image-converter
Summary:        Nautilus Image Converter
License:        GPL-2.0-or-later
Group:          Productivity/Graphics/Convertors
Version:        0.4.0
Release:        2.2
URL:            https://gitlab.gnome.org/coreyberla/nautilus-image-converter
Source:         %{name}-%{version}.tar.xz
# PATCH-FIX-UPSTREAM
Patch0:         nautilus-image-converter-fix-translations.patch
BuildRequires:  meson >= 0.49
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(glib-2.0) >= 2.28.0
BuildRequires:  pkgconfig(gtk4) >= 4.6.0
BuildRequires:  pkgconfig(libnautilus-extension-4) >= 43.rc
Recommends:     ImageMagick

%description
The Nautilus-Image-Converter extension allows you to resize/rotate images
from Nautilus.

%lang_package

%prep
%autosetup -p1

%build
%meson
%meson_build

%install
%meson_install
%find_lang %{name}

%files
%license COPYING
%doc AUTHORS ChangeLog NEWS
%{nautilus_extdir}/libnautilus-image-converter.so
%dir %{_datadir}/nautilus-image-converter
%{_datadir}/nautilus-image-converter/nautilus-image-resize.ui
%{_datadir}/nautilus-image-converter/nautilus-image-rotate.ui

%files lang -f %{name}.lang

%changelog
* Thu Mar  7 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Add nautilus-image-converter-fix-translations.patch: Fix build
  with gettext 0.22.
* Thu Sep 15 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.4.0:
  + Port to GTK4
  + Port to libnautilus-extension-4
  + Port to Meson
  + Fix progress window
  + Misc ui cleanup
- Switch to source service git checkout.
- Drop nautilus-image-converter-git.patch: Fixed upstream.
- Changes in BuildRequires:
  + Drop: gnome-common, gtk3-devel, intltool and nautilus-devel.
  + Add: meson, pkgconfig, pkgconfig(libnautilus-extension-4),
    pkgconfig(gtk4) and pkgconfig(glib-2.0).
- Modernize spec, use meson macros following upstreams port.
* Thu Jan 30 2020 Dominique Leuenberger <dimstar@opensuse.org>
- No longer recommend -lang: supplements are in use
* Fri Apr 20 2012 vuntz@opensuse.org
- Remove empty clean section, thanks to Sascha Peilicke for
  spotting this.
* Fri Apr  6 2012 vuntz@opensuse.org
- Add nautilus-image-converter-git.patch to update to git version:
  + Port to Gtk3/GNOME3.
  + Build fixes.
- Changes from version 0.3.0:
  + Port to Nautilus 2.21 / GIO.
  + Updated translations.
- Drop nautilus-image-converter-0.2.1-extensiondir.patch: fixed
  upstream.
- Change gtk2-devel BuildRequires to gtk3-devel: code was ported to
  GNOME 3 technologies.
- Remove gnome-vfs2-devel and libglade2-devel BuildRequires: code
  was ported to GNOME 3 technologies.
- Add gnome-common BuildRequires and change autoreconf call to
  gnome-autogen.sh, to enable proper use of
  nautilus-image-converter-git.patch.
- Change Requires of lang subpackage to Recommends.
- Remove nautilus Requires: the automatic Requires on the nautilus
  library is enough.
* Wed May 26 2010 dimstar@opensuse.org
- Use proper RPM group: Productivity/Graphics/Convertors.
* Tue May 25 2010 cristian.rodriguez@opensuse.org
- Add nautilus-image-converter-0.2.1-extensiondir.patch to read
  extension destination folder from nautilus.pc
- Require proper version of nautilus.
* Mon Jun 22 2009 vuntz@novell.com
- Remove checks for old versions of openSUSE.
- Recommends ImageMagick.
- Add lang package.
- Clean up file list.
* Mon Jun 15 2009 dominique-obs@leuenberger.net
- Added header to spec file, split BuildRequires on lines by 1
- use find_lang to properly mark the language files.
